Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit 1c50968


[ROCm/hip commit: 32e11e7dc6]
This commit is contained in:
Alex Voicu
2017-11-29 21:49:10 +00:00
rodzic cd61d38118
commit 8d51eaafb6
63 zmienionych plików z 171 dodań i 173 usunięć
@@ -35,7 +35,7 @@ THE SOFTWARE.
template<typename T>
__global__ void Inc(hipLaunchParm lp, T *Array){
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
int tx = threadIdx.x + blockIdx.x * blockDim.x;
Array[tx] = Array[tx] + T(1);
}